@@ -39,6 +39,7 @@ from .paginator import (
 )
 from .type_defs import (
     AdditionalAuthenticationProviderTypeDef,
+    AppSyncRuntimeTypeDef,
     AssociateApiResponseTypeDef,
     CachingConfigTypeDef,
     CreateApiCacheResponseTypeDef,
@@ -51,6 +52,7 @@ from .type_defs import (
     CreateTypeResponseTypeDef,
     DynamodbDataSourceConfigTypeDef,
     ElasticsearchDataSourceConfigTypeDef,
+    EvaluateCodeResponseTypeDef,
     EvaluateMappingTemplateResponseTypeDef,
     GetApiAssociationResponseTypeDef,
     GetApiCacheResponseTypeDef,
@@ -230,12 +232,14 @@ class AppSyncClient(BaseClient):
         apiId: str,
         name: str,
         dataSourceName: str,
-        functionVersion: str,
         description: str = ...,
         requestMappingTemplate: str = ...,
         responseMappingTemplate: str = ...,
+        functionVersion: str = ...,
         syncConfig: SyncConfigTypeDef = ...,
-        maxBatchSize: int = ...
+        maxBatchSize: int = ...,
+        runtime: AppSyncRuntimeTypeDef = ...,
+        code: str = ...
     ) -> CreateFunctionResponseTypeDef:
         """
         Creates a `Function` object.
@@ -277,7 +281,9 @@ class AppSyncClient(BaseClient):
         pipelineConfig: PipelineConfigTypeDef = ...,
         syncConfig: SyncConfigTypeDef = ...,
         cachingConfig: CachingConfigTypeDef = ...,
-        maxBatchSize: int = ...
+        maxBatchSize: int = ...,
+        runtime: AppSyncRuntimeTypeDef = ...,
+        code: str = ...
     ) -> CreateResolverResponseTypeDef:
         """
         Creates a `Resolver` object.
@@ -368,6 +374,16 @@ class AppSyncClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#disassociate_api)
         """
 
+    def evaluate_code(
+        self, *, runtime: AppSyncRuntimeTypeDef, code: str, context: str, function: str = ...
+    ) -> EvaluateCodeResponseTypeDef:
+        """
+        Evaluates the given code and returns the response.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Client.evaluate_code)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/client/#evaluate_code)
+        """
+
     def evaluate_mapping_template(
         self, *, template: str, context: str
     ) -> EvaluateMappingTemplateResponseTypeDef:
@@ -669,12 +685,14 @@ class AppSyncClient(BaseClient):
         name: str,
         functionId: str,
         dataSourceName: str,
-        functionVersion: str,
         description: str = ...,
         requestMappingTemplate: str = ...,
         responseMappingTemplate: str = ...,
+        functionVersion: str = ...,
         syncConfig: SyncConfigTypeDef = ...,
-        maxBatchSize: int = ...
+        maxBatchSize: int = ...,
+        runtime: AppSyncRuntimeTypeDef = ...,
+        code: str = ...
     ) -> UpdateFunctionResponseTypeDef:
         """
         Updates a `Function` object.
@@ -716,7 +734,9 @@ class AppSyncClient(BaseClient):
         pipelineConfig: PipelineConfigTypeDef = ...,
         syncConfig: SyncConfigTypeDef = ...,
         cachingConfig: CachingConfigTypeDef = ...,
-        maxBatchSize: int = ...
+        maxBatchSize: int = ...,
+        runtime: AppSyncRuntimeTypeDef = ...,
+        code: str = ...
     ) -> UpdateResolverResponseTypeDef:
         """
         Updates a `Resolver` object.
