@@ -33,8 +33,7 @@ Usage::
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import TypeDefinitionFormatType
 from .type_defs import (
@@ -69,14 +68,14 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListApiKeysPaginator(Boto3Paginator):
+class ListApiKeysPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListApiKeys)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators/#listapikeyspaginator)
     """
 
     def paginate(
-        self, *, apiId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, apiId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListApiKeysResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListApiKeys.paginate)
@@ -84,14 +83,14 @@ class ListApiKeysPaginator(Boto3Paginator):
         """
 
 
-class ListDataSourcesPaginator(Boto3Paginator):
+class ListDataSourcesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListDataSources)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators/#listdatasourcespaginator)
     """
 
     def paginate(
-        self, *, apiId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, apiId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDataSourcesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListDataSources.paginate)
@@ -99,14 +98,14 @@ class ListDataSourcesPaginator(Boto3Paginator):
         """
 
 
-class ListFunctionsPaginator(Boto3Paginator):
+class ListFunctionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListFunctions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators/#listfunctionspaginator)
     """
 
     def paginate(
-        self, *, apiId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, apiId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListFunctionsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListFunctions.paginate)
@@ -114,14 +113,14 @@ class ListFunctionsPaginator(Boto3Paginator):
         """
 
 
-class ListGraphqlApisPaginator(Boto3Paginator):
+class ListGraphqlApisPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators/#listgraphqlapispaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListGraphqlApisResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListGraphqlApis.paginate)
@@ -129,14 +128,14 @@ class ListGraphqlApisPaginator(Boto3Paginator):
         """
 
 
-class ListResolversPaginator(Boto3Paginator):
+class ListResolversPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListResolvers)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators/#listresolverspaginator)
     """
 
     def paginate(
-        self, *, apiId: str, typeName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, apiId: str, typeName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListResolversResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListResolvers.paginate)
@@ -144,14 +143,14 @@ class ListResolversPaginator(Boto3Paginator):
         """
 
 
-class ListResolversByFunctionPaginator(Boto3Paginator):
+class ListResolversByFunctionPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators/#listresolversbyfunctionpaginator)
     """
 
     def paginate(
-        self, *, apiId: str, functionId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, apiId: str, functionId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListResolversByFunctionResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListResolversByFunction.paginate)
@@ -159,7 +158,7 @@ class ListResolversByFunctionPaginator(Boto3Paginator):
         """
 
 
-class ListTypesPaginator(Boto3Paginator):
+class ListTypesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListTypes)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appsync/paginators/#listtypespaginator)
@@ -170,7 +169,7 @@ class ListTypesPaginator(Boto3Paginator):
         *,
         apiId: str,
         format: TypeDefinitionFormatType,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTypesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appsync.html#AppSync.Paginator.ListTypes.paginate)
